import { APIResponseObject } from "../../../types";
import loginUser from "../../../actions/users/login-user";

type Param = {
    user: {
        email: string;
    };
    social_platform: string;
    invitation?: any;
    database?: string;
    additionalFields?: string[];
    debug?: boolean;
};

/**
 * Function to login social user
 * ==============================================================================
 * @description This function logs in the user after 'handleSocialDb' function finishes
 * the user creation or confirmation process
 */
export default async function loginSocialUser({
    user,
    social_platform,
    invitation,
    database,
    additionalFields,
    debug,
}: Param): Promise<APIResponseObject> {
    const finalDbName = database ? database : "datasquirel";

    let userPayload = await loginUser({
        database: finalDbName,
        payload: { email: user.email },
        skipPassword: true,
        skipWriteAuthFile: true,
        additionalFields,
        debug,
        useLocal: true,
    });

    return userPayload;
}
